.. currentmodule:: clouddrift

API
===

Auto-generated summary of CloudDrift's API. For more details and examples, refer to the different Jupyter Notebooks.

Dataformat
----------

.. automodule:: clouddrift.dataformat
  :members:
  :undoc-members:

Select
---------
.. automodule:: clouddrift.select
  :members:
  :undoc-members:

Spectrum
--------
.. automodule:: clouddrift.timeseries
   :members:
   :undoc-members:
